//
//  AutoTableView.m
//  AutoTableView
//
//  Created by Zhichao Ma on 2017/8/15.
//  Copyright © 2017年 Zhichao Ma. All rights reserved.
//

#import "AutoTableView.h"
#import "AutoTableViewCell.h"
#import "ModelFrame.h"
#import "QuestionModel.h"
@interface AutoTableView ()<AutoTableViewDelegate>
{
    UIMenuItem * reformMenuItem; //重写
    UIMenuItem * deleteMenuItem; //删除
    NSIndexPath *longIndexPath;
}
@property (nonatomic, strong) NSArray *dbArray;
@end

@implementation AutoTableView
// 懒加载
-(NSArray *)dbArray{
    if (!_dbArray ) {
        //        NSMutableArray *mDbArray = [NSMutableArray arrayWithCapacity:5];
        
        NSString *path = [[NSBundle mainBundle]pathForResource:@"Answer.plist" ofType:nil];
        NSArray *answerArr = [NSArray arrayWithContentsOfFile:path];
        
        _dbArray = answerArr;
    }
    
    return _dbArray;
}
//初始化
-(instancetype)initWithFrame:(CGRect)frame style:(UITableViewStyle)style{
    if (self = [super initWithFrame:frame style:style]) {
        self.delegate = self;
        self.dataSource = self;
    }
    return self;
}
-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return self.dataArray.count;
}
-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    AutoTableViewCell *cell = [AutoTableViewCell cellWithTableView:self];
    
    cell.index = indexPath.row;
    
    cell.modelFrame = self.dataArray[indexPath.row];
    
    cell.sd_delegate = self;
    
    return cell;
}

-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    return [self.dataArray[indexPath.row] cellH];
}
-(void)addItem{
    [self beginUpdates];
    NSIndexPath *reloadIndexPath = [NSIndexPath indexPathForRow:self.dataArray.count -2 inSection:0];
    [self reloadRowsAtIndexPaths:@[reloadIndexPath] withRowAnimation:UITableViewRowAnimationNone];
    
    NSIndexPath *insertIndexPath = [NSIndexPath indexPathForRow:self.dataArray.count -1 inSection:0];
    [self insertRowsAtIndexPaths:@[insertIndexPath] withRowAnimation:UITableViewRowAnimationNone];
    [self endUpdates];
}

-(void)deleteItemFrom:(NSInteger)from{
    
}

-(void)AutoTableViewCellLongPress:(UILongPressGestureRecognizer *)longPressGr{
    CGPoint location       = [longPressGr locationInView:self];
    NSIndexPath *indexPath = [self indexPathForRowAtPoint:location];
    if (indexPath.row == self.dataArray.count -1) return;
    longIndexPath         = indexPath;
    
    id object              = [self.dataArray objectAtIndex:indexPath.row];
    if (![object isKindOfClass:[ModelFrame class]]) return;
    AutoTableViewCell *cell = [self cellForRowAtIndexPath:indexPath];
    if (longPressGr.state == UIGestureRecognizerStateBegan){
        [self showMenuViewController:cell.subTitle0 andIndexPath:indexPath];
    }

}
- (void)showMenuViewController:(UIView *)showInView andIndexPath:(NSIndexPath *)indexPath
{
    [self becomeFirstResponder];
    if (reformMenuItem   == nil) {
        reformMenuItem   = [[UIMenuItem alloc] initWithTitle:@"重做" action:@selector(reformMessage:)];
    }
    if (deleteMenuItem == nil) {
        deleteMenuItem = [[UIMenuItem alloc] initWithTitle:@"删除" action:@selector(deleteMessage:)];
    }
    
    UIMenuController *menu =[UIMenuController sharedMenuController];
    [menu setMenuItems:@[reformMenuItem,deleteMenuItem]];
    [menu setTargetRect:showInView.frame inView:showInView.superview];
    [menu setMenuVisible:YES animated:YES];
    
}

- (void)reformMessage:(UIMenuItem *)reformMenuItem
{
    // 添加的数据
    NSDictionary *dic = self.dbArray[arc4random()%self.dbArray.count];
    
    QuestionModel *questionModel = [QuestionModel questionModelWithDic:dic];
    
    // 转化为frameModel
    ModelFrame *frame = [[ModelFrame alloc]init];
    frame.autoModel = questionModel;

    [self.dataArray replaceObjectAtIndex:longIndexPath.row withObject:frame];
    [self statusChangedFrom:longIndexPath.row + 1];
}

- (void)deleteMessage:(UIMenuItem *)deleteMenuItem
{
    if (longIndexPath.row != 0) {
    
        NSDictionary *dic = self.dbArray[arc4random()%self.dbArray.count];
        
        QuestionModel *questionModel = [QuestionModel questionModelWithDic:dic];
        
        // 转化为frameModel
        ModelFrame *frame = [[ModelFrame alloc]init];
        frame.autoModel = questionModel;

        [self.dataArray replaceObjectAtIndex:longIndexPath.row -1 withObject:frame];
    }
    // 这里还应该把本地的消息附件删除
    [self statusChangedFrom:longIndexPath.row];
}
- (void)statusChangedFrom:(NSInteger)from
{
    
    NSMutableArray *arr = [NSMutableArray arrayWithCapacity:2];
    for (NSInteger i = from; i < self.dataArray.count; i ++) {
        [arr addObject:[NSIndexPath indexPathForRow:i inSection:0]];
    }
    [self.dataArray removeObjectsInRange:NSMakeRange(from, self.dataArray.count - from )];
    
    [self beginUpdates];
   
    [self deleteRowsAtIndexPaths:arr.copy withRowAnimation:UITableViewRowAnimationFade];
    @try {
        NSIndexPath *indexpath = [NSIndexPath indexPathForRow:from -1 inSection:0];
        [self reloadRowsAtIndexPaths:@[indexpath] withRowAnimation:UITableViewRowAnimationNone];
        
    } @catch (NSException *exception) {
        
    }
    [self endUpdates];
    
}
//处理action事件
- (BOOL)canPerformAction:(SEL)action withSender:(id)sender {
    if(action == @selector(reformMessage:)){
        return YES;
        
    } else if (action == @selector(deleteMessage:)){
        return YES;
    }else {
        return [super canPerformAction:action withSender:sender];
        
    }
    
}
-(BOOL)canBecomeFirstResponder{
    return YES;
    
}
@end
