//
//  AutoTableViewCell.m
//  AutoTableView
//
//  Created by Zhichao Ma on 2017/8/15.
//  Copyright © 2017年 Zhichao Ma. All rights reserved.
//

#import "AutoTableViewCell.h"
#import "QuestionModel.h"
#import "AnswerItemModel.h"
#import "ModelFrame.h"
#import "SDChatMessageConst.h"
#define BaseTag(x) (1000+x)

#define titleNormalColor [UIColor blackColor]
#define titleSelectColor [UIColor grayColor]

#define subBtnNormalColor [UIColor grayColor]
#define subBtnSelectColor [UIColor grayColor]
#define LabelFont(x) [UIFont systemFontOfSize:x]

@interface AutoTableViewCell ()

@property (nonatomic, strong) UILabel *tagLabel;

@property (nonatomic, strong) UILabel *titleLabel;

@property (nonatomic, strong) UIButton *subTitle1;

@property (nonatomic, strong) UIButton *subTitle2;

@property (nonatomic, strong) UIButton *subTitle3;

@property (nonatomic, strong) UIButton *subTitle4;

@property (nonatomic, strong) UIButton *subTitle5;

@property (nonatomic, strong) UIButton *subTitle6;

@property (nonatomic, strong) UIButton *subTitle7;

@end

@implementation AutoTableViewCell

+(instancetype)cellWithTableView:(UITableView *)tableView{
    static NSString *autoTableViewCellId = @"AutoTableViewCellId";
    AutoTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:autoTableViewCellId];
    if (cell == nil) {
        
        cell =[[AutoTableViewCell alloc]initWithStyle:UITableViewCellStyleDefault reuseIdentifier:autoTableViewCellId];

        cell.selectionStyle = UITableViewCellSelectionStyleNone;
    }
    return cell;
}
-(instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier{
    self =[super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if ( self) {
        
        self.backgroundColor = [UIColor clearColor];//[UIColor colorWithRed:arc4random()%255/255.0 green:arc4random()%255/255.0 blue:arc4random()%255/255.0 alpha:1.0];/
        
        [self setUpUI];
    }
    
    return self;
}

-(void)setUpUI{
    
    UILabel *tagLabel = [[UILabel alloc]initWithFrame:CGRectMake(0, 9, 40, 20)];
    tagLabel.textColor = titleNormalColor;
    tagLabel.font = LabelFont(15);
    tagLabel.textAlignment = NSTextAlignmentRight;
    _tagLabel = tagLabel;
    [self.contentView addSubview:tagLabel];
    
    UILabel *titleLabel = [[UILabel alloc]init];
    titleLabel.textColor = titleNormalColor;
    titleLabel.font = LabelFont(15);
    titleLabel.numberOfLines = 0;
    _titleLabel = titleLabel;
    
    [self.contentView addSubview:titleLabel];
    
    for (int i = 0; i < 8; i++) {
        UIButton *btn = [UIButton buttonWithType:UIButtonTypeCustom];
        
        btn.titleLabel.font = LabelFont(13);
        btn.titleLabel.numberOfLines = 0;
        
        btn.contentVerticalAlignment = UIControlContentVerticalAlignmentTop;
        btn.contentHorizontalAlignment = UIControlContentHorizontalAlignmentLeft;
        
        [btn setTitleColor:subBtnNormalColor forState:UIControlStateNormal];
        [btn setTitleColor:subBtnSelectColor forState:UIControlStateSelected];
        
        btn.tag = BaseTag(i);
        
        btn.hidden = YES;
        
        [btn addTarget:self action:@selector(selectItem:) forControlEvents:UIControlEventTouchUpInside];
        
        switch (i) {
            case 0:
                _subTitle0 = btn;
                break;
            case 1:
                _subTitle1 = btn;
                break;
            case 2:
                _subTitle2 = btn;
                break;
            case 3:
                _subTitle3 = btn;
                break;
            case 4:
                _subTitle4 = btn;
                break;
            case 5:
                _subTitle5 = btn;
                break;
            case 6:
                _subTitle6 = btn;
                break;
            case 7:
                _subTitle7 = btn;
                break;
            default:
                btn = nil;
                break;
        }
        if (btn) {
            [self.contentView addSubview:btn];
        }
    }
    
    self.contentView.userInteractionEnabled = YES;
    
    UILongPressGestureRecognizer *longPress = [[UILongPressGestureRecognizer alloc]initWithTarget:self action:@selector(longPress:)];
    longPress.minimumPressDuration = 0.5;
    
    [self.contentView addGestureRecognizer:longPress];
}
-(void)selectItem:(UIButton *)sender{
    [[NSNotificationCenter defaultCenter]postNotificationName:SelectItemNotification object:@[self.modelFrame,[NSNumber numberWithInteger:sender.tag - 1000]]];
}
-(void)longPress:(UILongPressGestureRecognizer *)longPressGr{
    NSLog(@"长按");
    if ([self.sd_delegate respondsToSelector:@selector(AutoTableViewCellLongPress:)]) {
        [self.sd_delegate AutoTableViewCellLongPress:longPressGr];
    }
}
- (void)allHide{
    _subTitle0.hidden = YES;
    _subTitle1.hidden = YES;
    _subTitle2.hidden = YES;
    _subTitle3.hidden = YES;
    _subTitle4.hidden = YES;
    _subTitle5.hidden = YES;
    _subTitle6.hidden = YES;
    _subTitle7.hidden = YES;
    _subTitle0.userInteractionEnabled = YES;
    _subTitle1.userInteractionEnabled = YES;
    _subTitle2.userInteractionEnabled = YES;
    _subTitle3.userInteractionEnabled = YES;
    _subTitle4.userInteractionEnabled = YES;
    _subTitle5.userInteractionEnabled = YES;
    _subTitle6.userInteractionEnabled = YES;
    _subTitle7.userInteractionEnabled = YES;
}
-(void)setModelFrame:(ModelFrame *)modelFrame{
    _modelFrame = modelFrame;
    QuestionModel *questionModel = modelFrame.autoModel;
    _titleLabel.text = questionModel.title;
    _tagLabel.text = [NSString stringWithFormat:@"%ld、",self.index + 1];
    [self allHide];
    if (modelFrame.select) {
        _titleLabel.textColor = titleSelectColor;
        _tagLabel.textColor = titleSelectColor;
        _subTitle0.hidden = NO;
        _subTitle0.selected = YES;
        AnswerItemModel *answer = questionModel.answers[0];
        [_subTitle0 setTitle:answer.answer forState:UIControlStateSelected];
        _subTitle0.userInteractionEnabled = NO;
    
    }else{
        _titleLabel.textColor = titleNormalColor;
        _tagLabel.textColor = titleNormalColor;
        NSArray *answers = questionModel.answers;
        for (int i = 0 ; i < answers.count; i++) {
            AnswerItemModel *answerItem = answers[i];
            NSString *str = answerItem.answer;
            switch (i) {
                case 0:
                    _subTitle0.hidden = NO;
                    _subTitle0.selected = NO;
                    [_subTitle0 setTitle:str forState:UIControlStateNormal];
                    break;
                case 1:
                    _subTitle1.hidden = NO;
                    _subTitle1.selected = NO;
                    [_subTitle1 setTitle:str forState:UIControlStateNormal];
                    break;
                case 2:
                    _subTitle2.hidden = NO;
                    _subTitle2.selected = NO;
                    [_subTitle2 setTitle:str forState:UIControlStateNormal];
                    break;
                case 3:
                    _subTitle3.hidden = NO;
                    _subTitle3.selected = NO;
                    [_subTitle3 setTitle:str forState:UIControlStateNormal];
                    break;
                case 4:
                    _subTitle4.hidden = NO;
                    _subTitle4.selected = NO;
                    [_subTitle4 setTitle:str forState:UIControlStateNormal];
                    break;
                case 5:
                    _subTitle5.hidden = NO;
                    _subTitle5.selected = NO;
                    [_subTitle5 setTitle:str forState:UIControlStateNormal];
                    break;
                case 6:
                    _subTitle6.hidden = NO;
                    _subTitle6.selected = NO;
                    [_subTitle6 setTitle:str forState:UIControlStateNormal];
                    break;
                case 7:
                    _subTitle7.hidden = NO;
                    _subTitle7.selected = NO;
                    [_subTitle7 setTitle:str forState:UIControlStateNormal];
                    break;
                default:
                    break;
            }
        }

    }
}
-(void)layoutSubviews{
    [super layoutSubviews];
    
    _titleLabel.frame = self.modelFrame.titleFrame;
    for (int i = 0; i < self.modelFrame.subAnswerFrames.count; i++) {
        NSValue *value = self.modelFrame.subAnswerFrames[i];
        CGRect rect = [value CGRectValue];
        switch (i) {
            case 0:
                _subTitle0.frame = rect;
                break;
            case 1:
                _subTitle1.frame = rect;
                break;
            case 2:
                _subTitle2.frame = rect;
                break;
            case 3:
                _subTitle3.frame = rect;
                break;
            case 4:
                _subTitle4.frame = rect;
                break;
            case 5:
                _subTitle5.frame = rect;
                break;
            case 6:
                _subTitle6.frame = rect;
                break;
            case 7:
                _subTitle7.frame = rect;
                break;
    
            default:
                break;
        }
    }
}
- (void)awakeFromNib {
    [super awakeFromNib];
    // Initialization code
}

- (void)setSelected:(BOOL)selected animated:(BOOL)animated {
    [super setSelected:selected animated:animated];

    // Configure the view for the selected state
}

@end
